@@ -1,8 +1,8 @@
 from enum import auto
 
-from pydantic import BaseModel
+from pydantic import BaseModel, constr
 
-from ...utils import AutoValueEnum
+from stac_pydantic.utils import AutoValueEnum
 
 
 class SortDirections(str, AutoValueEnum):
@@ -15,5 +15,5 @@ class SortExtension(BaseModel):
     https://github.com/radiantearth/stac-api-spec/tree/master/extensions/sort#sort-api-extension
     """
 
-    field: str
+    field: constr(min_length=1)
     direction: SortDirections
